package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.SrsKnrdType;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 困难类型Mapper接口
 *
 * @author srs
 * @date 2024-06-05
 */
public interface SrsKnrdTypeMapper extends BaseMapper<SrsKnrdType> {
    /**
     * 查询困难类型
     *
     * @param id 困难类型主键
     * @return 困难类型
     */
    public SrsKnrdType selectSrsKnrdTypeById(Long id);

    /**
     * 查询困难类型列表
     *
     * @param srsKnrdType 困难类型
     * @return 困难类型集合
     */
    List<SrsKnrdType> selectSrsKnrdTypeList(SrsKnrdType srsKnrdType);

    /**
     * 新增困难类型
     *
     * @param srsKnrdType 困难类型
     * @return 结果
     */
    int insertSrsKnrdType(SrsKnrdType srsKnrdType);

    /**
     * 修改困难类型
     *
     * @param srsKnrdType 困难类型
     * @return 结果
     */
    int updateSrsKnrdType(SrsKnrdType srsKnrdType);

    /**
     * 删除困难类型
     *
     * @param id 困难类型主键
     * @return 结果
     */
    int deleteSrsKnrdTypeById(Long id);

    /**
     * 批量删除困难类型
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSrsKnrdTypeByIds(Long[] ids);
}
